#
# spec file for package orbit2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name ORBit2
Name:           orbit2
Version:        2.14.19
Release:        lp152.4.4
Summary:        CORBA Object Request Broker
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            http://www.gnome.org/
Source:         ftp://ftp.gnome.org/pub/gnome/sources/ORBit2/2.14/%{_name}-%{version}.tar.bz2
Source99:       baselibs.conf
BuildRequires:  gtk-doc
BuildRequires:  libidl-devel
Provides:       ORBit2

%description
ORBit is a CORBA (Common Object Request Broker
Architecture) ORB (Object Request Broker). It allows programs to send
requests and receive replies from other programs, regardless of the
locations of the two programs. CORBA is an architecture that enables
communication between program objects, regardless of the programming
language they are written in or the operating system they run on.

You will need to install this package if you want to run programs that
use the CORBA technology ORBit implementation.

%package devel
Summary:        Development files for the orbit2 CORBA implementation
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libidl-devel
Requires:       pkgconfig(glib-2.0)
Provides:       ORBit2-devel

%description devel
ORBit is a CORBA (Common Object Request Broker
Architecture) ORB (object request broker). It allows programs to send
requests and receive replies from other programs, regardless of the
locations of the two programs. CORBA is an architecture that enables
communication between program objects, regardless of the programming
language they are written in or the operating system they run on.

You will need to install this package if you want to run programs that
use the ORBit implementation of the CORBA technology.

%package doc
Summary:        Documentation for the orbit2 CORBA implementation
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Documentation/HTML
Requires:       %{name} = %{version}
Provides:       ORBit2-doc
BuildArch:      noarch

%description doc
ORBit is a CORBA (Common Object Request Broker Architecture) ORB
(Object Request Broker).

You will need to install this package if you want to run programs that
use the CORBA technology ORBit implementation.

%prep
%setup -q -n %{_name}-%{version}

%build
%if 0%{?suse_version} < 1550
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%endif
%configure \
	--disable-static
echo "#undef G_DISABLE_DEPRECATED" >> config.h
# Do not use parallel make since there is a .deps directory creation
# race in idl-compiler/orbit-idl-c-backend.c:out_for_pass
make -j1

%install
%make_install
%if 0%{?suse_version} >= 1550
find %{buildroot} -type f -name "*.a" -delete -print
%endif
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS README TODO
%{_bindir}/linc-cleanup-sockets
%{_libdir}/*.so.*
%{_libdir}/orbit-2.0/

%files devel
%{_bindir}/ior-decode-2
%{_bindir}/orbit-idl-2
%{_bindir}/orbit2-config
%{_bindir}/typelib-dump
%{_includedir}/orbit-2.0/
%{_libdir}/*.so
%if 0%{?suse_version} < 1550
%{_libdir}/libname-server-2.a
%endif
%{_libdir}/pkgconfig/ORBit-*.pc
%{_datadir}/aclocal/ORBit2.m4
%{_datadir}/idl/orbit-2.0/

%files doc
%doc %{_datadir}/gtk-doc/html/ORBit2/

%changelog
* Thu Dec  5 2019 Michael Gorse <mgorse@suse.com>
- Re-add libname-server2.a to -devel package on SLE/Leap. It is
  needed to build libbonobo, which SLE still needs to ship.
- Pass -ffat-lto-objects to CFLAGS on SLE/Leap; needed for static
  library.
- Minor spec clean-up.
* Sat Sep  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Delete static build from devel package.
* Mon Mar  5 2018 jengelh@inai.de
- Update RPM groups, trim descriptions and ensure neutrality of it.
* Mon Mar  5 2018 dimstar@opensuse.org
- Modernize spec file using spec-cleaner.
* Mon Dec 16 2013 uweigand@de.ibm.com
- Disable parallel make due to directory creation race.
* Thu Mar  7 2013 dimstar@opensuse.org
- Add "#undef G_DISABLE_DEPRECATED" to the generated config.h, to
  allow the usage of deprectaed glib symbols (e.g. g_thread_*).
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Thu Dec 22 2011 vuntz@opensuse.org
- Explicitly list files we package.
* Tue Sep 28 2010 lmedinas@opensuse.org
- Update to version 2.14.19:
  + fix free on error of uninitialized IOR components
- Drop orbit2-crash.patch: fixed upstream.
* Fri Apr 23 2010 lzwang@novell.com
- bnc#598867: Add orbit2-crash.patch to fix crasher with corrupted
  ~/.gconfd/saved_state ...
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.14.18:
  + add a g_warning
  + fix FMR in forwarding code
  + fix some problems with the preprocessor on Solaris
  + add a CORBA_wstring_dup function
* Thu Dec 17 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Make doc subpackage a noarch package
* Fri Mar 27 2009 vuntz@novell.com
- Remove all .la files.
- Package explicitly /usr/lib/libname-server-2.a because there's no
  dynamic library for it.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.14.17:
  + fix glib single includes
  + various fixes for cross-compiling
  + do fewer DNS lookups in linc
  + fix compiler warnings
  + threading fixes
  + win32 portability fixes
- Remove BuildRequires: indent, openssl-devel, popt-devel,
  xmlcharent
- Remove indent and popt-devel from Requires of devel package.
- Remove AutoReqProv: it's default now.
- Remove -fno-strict-aliasing from CFLAGS.
- Use parallel build.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun Sep 21 2008 mboman@suse.de
- Update to version 2.14.16:
  + fix make check on Mac OS/X
  + The ORBNetID option was not consistent in relation to
    ORBIIOPIPName. This fix ensures that ORBIIOPIPName always
    takes precedence.
* Tue Sep 16 2008 vuntz@novell.com
- Update to version 2.14.15:
  + fix some leaks
  + fix some of the changes in 2.14.14
  + fix potential make loop
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.14.14:
  + Use ORBIT_SOCKETDIR to propagate the socket dir to children
    wherever possible; this has two benefits: it speeds up ORBit2
    launch and it and it allows root owned apps to talk to the
    user's AT
  + Various linc2 fixes.
* Fri Jul 18 2008 jpr@suse.de
- Drop orbit-abuild.patch, the warning is valid but causes no
  issues and will be fixed nicely upstream
* Fri Jun  6 2008 maw@suse.de
- Update to version 2.14.13:
  + Robustness fixes
  + Fixes for the poa test client
  + Build fixes with single glib includes
  + Locking fixes in linc
  + Fixes for handling of local requests
- Remove upstreamed patch: libbonobo-deadlock-fix.patch.
* Fri May 23 2008 maw@suse.de
- Add libbonobo-deadlock-fix.patch (bnc#393634 and bgo$534351)
- s#%%run_ldconfig#/sbin/ldconfig#.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jan 30 2008 maw@suse.de
- Update to version 2.14.12:
  + Fix the build when using glib 2.15.
* Fri Jan 25 2008 maw@suse.de
- Update to version 2.14.11:
  + Various cleanups and fixes for win32
  + Fix off by one in all method name lengths
  + Fixes interoperability with other ORBs.
* Fri Nov 23 2007 maw@suse.de
- Update to version 2.14.10:
  + Bug fixes
- Rename abuild.patch to orbit-abuild.patch.
* Mon Sep 17 2007 gekker@suse.de
- Update to version 2.14.9
  * bug fixes
    + Portability fix (Tor Lillqvist)
    + Various fixes in GIOP and linc (Jules Colding)
* Tue Jul 31 2007 maw@suse.de
- Update to 2.14.8:
  * bug fixes
  + Fix GIOP timeouts and add unit tests (Jules Colding)
  + Code cleanups (Kjartan)
  + Fix pointer arithmetics (Roland Illig)
  + Fix crash with uninitialized exception (Vincent Untz)
    + ORBLocalOnly mode in Solaris fixes (Brian Cameron)
- Respin abuild.patch -- part of it has been upstreamed.
* Wed Mar 21 2007 maw@suse.de
- Update to 2.14.7
- Fix b.g.o 378454.
* Fri Feb 16 2007 maw@suse.de
- Update to 2.14.6
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Fri Jan  5 2007 sbrabec@suse.cz
- Spec file cleanup.
- Splitted orbit2-doc from orbit2-devel.
* Fri Jan  5 2007 maw@suse.de
- Move to /usr.
* Tue Jan  2 2007 jhargadon@suse.de
- Removed unneeded libtool files. (#223691)
* Tue Sep 12 2006 jhargadon@suse.de
- update to version 2.14.3
- Patch to correct problem where DHCP hostname changes caused login
  to block.
- Added gtk-doc documentation.
- Modify ORBLocalOnly test for TCP/IP connections so that differences
  in the port number does not cause the test to fail.  Since the port
  number does not affect whether the IP address is local, this should
  make the test work properly on platforms where the access ()
  function fills in the port value that is being compared.  On
  Solaris, this fixes a bug that causes Java a11y to break, from an
  end-user perspective.
- configure.in (CFLAGS): Fix #147556
- acinclude.m4: Added AX_CFLAGS_GCC_OPTION
* Tue Sep 12 2006 jhargadon@suse.de
- update to version 2.14.2
- bug fixes
    + Don't hang when the hostname changes
    + Fix problems with a11y on Solaris
    + Doc improvements
    + Build fixes
* Mon Jul 31 2006 gekker@suse.de
- Update to version 2.14.1
- Remove upstreamed patch
  * bug fixes
    + Cleanups, leak fixes and fixes for reports
    from the Coverity checker (Kjartan, Pascal)
    + New function ORBit_get_giop_recv_limit().
    Clients must be able to retrieve the
    maximum allowed GIOP receive limit. (Jules Colding)
    + Bug 323201: marshalling of void retval typecode generated
    by "imodule service" crashes. (Gustavo Carneiro)
    + emit per interface enum for index of xyz_imethods[].
    (Kuang-Chun Cheng)
    + Port to GOption (Christian Persch)
    + Win32 fixes (Tor Lillqvist)
    + Emit exception for bad URL in string_to_object
    (Frank Rehberger)
    + Fix C++ compatibility in generated code (Vladimir Panov)
* Fri Jul 21 2006 gekker@suse.de
- Update to version 2.14.0
- Remove upstreamed patches
  * bug fixes
    + Fix build on Cygwin (Tor)
    + Fix giop test compilation/crash (Tor)
- update to ORBit2-2.13.3
  * bug fixes
    + Fix crash on null adaptor (Michael)
    + Fix compiler warnings (Kjartan, Jens Granseuer)
    + Improve configure stage on Win32 (Tor)
- update to ORBit2-2.13.2
  * bug fixes
    + realloc should update length/tracking information
    (Martin Blom)
    + Fix memory management and crashew when shutting down
    the ORB. (Anders Carlsson)
    + Build/correctness fixes (Tor, Jules)
- update to +ORBit2-2.13.1
  * features
    + More work on porting to Win32 (Tor)
    + Implement forward binding (Fernando Herrera)
    + Implement new ORB_init option ORBNetID (Jules Colding)
  * bug fixes
    + Build fix (James Henstridge)
    + Memory management fixes (Anders Carlsson)
    + Reset connection for forwarded objects (Anders)
    + Don't use -export-dynamic (Mark)
    + if we have failed on the unix socket, have IPv4 or
    IPv6 connections enabled and are on localhost, then
    don't connect on the corresponding port from the profiles
    (Arvind Samtur)
    + Fix a bunch of compiler warnings and make some code static
    (Kjartan)
    + Add threading libs to ORBIT_NAME (Michael)
    + Check for netdb.h (Sandie Vanderme)
    + Check for sys/sockio.h (James Andrewartha)
  * Other
    + Improve docs for users of ORBit2 (Jules Colding)
* Fri Jun  2 2006 gekker@suse.de
- Update patch to a better fix for (#178296)
* Wed May 24 2006 gekker@suse.de
- Fix race condition (#178296) -- mmeeks
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 gekker@suse.de
- Fix gnome-session-manager crash (b.g.o #322730) patch from mmeeks
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.12.4.
* Wed Aug 31 2005 gekker@suse.de
- Package linc-cleanup-sockets in base package (113508)
* Thu Aug 18 2005 gekker@suse.de
- Update to version 2.12.3
* Fri Aug 12 2005 gekker@suse.de
- Fix crash in gtk-file-chooser b.g.o(310270).
* Thu Jun 16 2005 gekker@suse.de
- Update to version 2.12.2
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Thu Apr 28 2005 ro@suse.de
- dropped dependency to linc-devel in devel package
* Thu Feb 10 2005 gekker@suse.de
- Updated to version 2.12.1
* Thu Nov 18 2004 gekker@suse.de
- Updated to version 2.12.0
* Wed Sep 29 2004 mmichael@suse.de
- Fix lockup
* Fri Sep 17 2004 clahey@suse.de
- Updated to version 2.10.5.
* Mon Jul  5 2004 jody@suse.de
- Updated to version 2.10.3 (GNOME 2.6).
* Thu Apr 15 2004 sbrabec@suse.cz
- Updated to version 2.10.0 (GNOME 2.6).
* Mon Feb 23 2004 sbrabec@suse.cz
- Fixed AC_DEFUN underquoting.
* Thu Feb  5 2004 hhetter@suse.de
- updated to version 2.8.3 [GNOME 2.4.2]
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.8.2.
* Tue Oct 14 2003 ro@suse.de
- do full autoreconf
* Fri Sep 26 2003 sbrabec@suse.cz
- Updated to version 2.8.0 (GNOME 2.4).
* Fri Aug 15 2003 sbrabec@suse.cz
- Updated to version 2.6.3.
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 12 2003 sbrabec@suse.cz
- Updated to version 2.6.2.
- Fixed directory packaging.
- Updated neededforbuild.
* Tue May 27 2003 hhetter@suse.de
- updated to version 2.6.1
* Wed May 14 2003 sbrabec@suse.cz
- Sync -devel Requires with pkgconfig (bug #26872).
* Wed Jan 29 2003 hhetter@suse.de
- updated to version 2.6.0
* Thu Oct 24 2002 sbrabec@suse.cz
- Update to version 2.5.0.
* Fri Oct 18 2002 sbrabec@suse.cz
- Update to version 2.4.3.
- Updated %%files. Fixed orbit2/orbit2-devel splitting.
* Tue Aug 20 2002 ro@suse.de
- fixed requires line for devel package
* Wed Aug 14 2002 hhetter@suse.de
- updated to version 2.4.1
* Fri Aug  9 2002 hhetter@suse.de
- add openssl to neededforbuild
* Tue Jun  4 2002 hhetter@suse.de
- updated to version 2.4.0, source frozen release
* Mon May 13 2002 meissner@suse.de
- %%_lib fixes
* Tue Apr  9 2002 hhetter@suse.de
- updated to version 2.3.107 [gnome desktop beta3]
* Thu Jan 31 2002 hhetter@suse.de
- updated to version 2.3.103 [gnome desktop alpha2]
    + big POA cleanup
    + unique id generator re-write
    + runtime debugging
    + idl compiler checks oneway's validity
    + union marshalling cleanup
    + allow multiple ORB:init calls
    + fix profile leaks
    + fix screwy idl compiler output
    + bomb out if alingment checks fail
* Fri Jan 11 2002 hhetter@suse.de
- updated to version 2.3.102:
  * fixed and improved regression tests
* Wed Dec 12 2001 hhetter@suse.de
- initial SuSE release for GNOME 2.0 platform
